@@ -2,8 +2,8 @@ from django.apps import AppConfig
 
 
 class DjsanaConfig(AppConfig):
-    name = 'djasana'
-    verbose_name = 'Asana'
+    name = "djasana"
+    verbose_name = "Asana"
 
     def ready(self):
         pass
