@@ -4,13 +4,13 @@ from django.db import migrations, models
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('djasana', '0020_adds_project_default_view'),
+        ("djasana", "0020_adds_project_default_view"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='customfield',
-            name='has_notifications_enabled',
+            model_name="customfield",
+            name="has_notifications_enabled",
             field=models.BooleanField(default=False),
         ),
     ]
